sqlobject.tests.test_select_through module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_select_through module

class `sqlobject.tests.test_select_through.` `SRThrough1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = sr_through1
  `q` = sr_through1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.SQLMultipleJoin object>]
    `joins` = [<sqlobject.joins.SOSQLMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_select_through.SRThrough1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sr_through1'
  property `three`
  property `threeID`
  property `twos`

class `sqlobject.tests.test_select_through.` `SRThrough2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addThree`(obj)
  `j` = sr_through2
  property `one`
  property `oneID`
  `q` = sr_through2
  `removeThree`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.SQLRelatedJoin object>]
    `joins` = [<sqlobject.joins.SOSQLRelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_select_through.SRThrough2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sr_through2'
  property `threes`

class `sqlobject.tests.test_select_through.` `SRThrough3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addSRThrough2`(obj)
  `j` = sr_through3
  property `name`
  property `ones`
  `q` = sr_through3
  `removeSRThrough2`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.SQLMultipleJoin object>, <sqlobject.joins.SQLRelatedJoin object>]
    `joins` = [<sqlobject.joins.SOSQLRelatedJoin object>, <sqlobject.joins.SOSQLMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_select_through.SRThrough3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sr_through3'
  property `twos`

`sqlobject.tests.test_select_through.` `setup_module`(mod)

`sqlobject.tests.test_select_through.` `testBadRef`()

`sqlobject.tests.test_select_through.` `testThroughFK`()

`sqlobject.tests.test_select_through.` `testThroughFKAndJoin`()

`sqlobject.tests.test_select_through.` `testThroughMultipleJoin`()

`sqlobject.tests.test_select_through.` `testThroughRelatedJoin`()